Django-page-cms's documentation
===============================

Contents:

.. toctree::
   :maxdepth: 2

   installation.rst
   page-api.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

